# -*- coding: utf-8 -*-

from .GatewayNotSupportedException import GatewayNotSupportedException

__all__ = ["GatewayNotSupportedException"]
